@@ -211,11 +211,11 @@ void command_reload(gpointer callback_data,guint callback_action,
 		ptw->cursor.x=ptw->cursor.y=ptw->top.x=ptw->top.y=0;
 		ptw->edit=FALSE;
 		set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
-					0,get_width_max(ptw),
+					0,get_width_max(ptw)+1,
 					MAX(ptw->drawing->allocation.width/ptw->fontwidth,1),
 																ptw->top.x);
 		set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
-					0,ptw->max-1,
+					0,ptw->max,
 					MAX(ptw->drawing->allocation.height/(ptw->fontheight),1),
 																ptw->top.y);
 		set_menu_bar(ptw);
@@ -515,10 +515,10 @@ void command_all(gpointer callback_data,guint callback_action,
 	set_menu_bar(ptw);
 	if (ptw->top.x!=top.x)
 		set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
-										0,get_width_max(ptw),sx,ptw->top.x);
+										0,get_width_max(ptw)+1,sx,ptw->top.x);
 	if (ptw->top.y!=top.y)
 		set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
-										0,ptw->max-1,sy,ptw->top.y);
+										0,ptw->max,sy,ptw->top.y);
 	gtk_widget_draw(ptw->drawing,NULL);
 }
 
