@@ -613,7 +613,7 @@ gboolean prompt_close(TEXTWND *ptw)
 	gchar *text;
 
 	if (ptw->edit) {
-		text=g_strdup_printf(_("File %s was edited\nSave?"),ptw->file);
+		text=g_strdup_printf(_("File %s was edited.\nSave?"),ptw->file);
 		switch (message_box("Text maid",text,0,
 										_("_Yes"),_("_No"),_("Cancel"),NULL)) {
 			case 0:
