@@ -1651,7 +1651,7 @@ void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 	} else if (data->selection==atom_textmaid0) {
 		/* ץ̿ */
 		instance=MAX(data->length,0);
-	} else if (data->selection==atom_textmaid1) {
+	} else if (data->selection==atom_textmaid1 && data->length>0) {
 		/* ץ̿ */
 		/* ޥɥ饤β */
 		argv=g_strsplit(data->data,"\n",G_MAXINT);
