@@ -16,11 +16,11 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
-#include <ctype.h>
 #include <locale.h>
-#include <stdlib.h>
+#include <string.h>
 #include <unistd.h>
 #include "tmaid.h"
+#include "argument.h"
 #include "charset.h"
 #include "command.h"
 #include "conf.h"
@@ -48,19 +48,21 @@ gchar *hisfile[10];					/* ե */
 gchar *openpath=NULL;				/* Υѥ */
 gchar *savepath=NULL;				/* ̾դ¸Υѥ */
 gchar *clipboard_text=NULL;			/* åץܡɤΥƥ */
+gchar *arg_text=NULL;				/* ץ̿ѿ */
 gint def_width,def_height;			/* ǥեȤΥɥΥ */
 gint ftnum=0;						/* ե륿פο */
 gint history=4;						/* ե */
+gint init_line=0;					/* ΥåȰ */
 gint instance=-1;					/* ץ̿ѿ */
 gint tcount=0;						/* ե륿פΥ */
 guint timer_id=0;					/* ID */
-COMM *comm=NULL;					/* ץ̿ѹ¤ */
 FTYPE *ftype=NULL;					/* ե륿 */
 GdkAtom atom_clipboard;				/* åץܡ */
 GdkAtom atom_targets;				/* å */
 GdkAtom atom_compound;				/* ѥ */
 GdkAtom atom_text;					/* ƥ */
-GdkAtom atom_textmaid;				/* ץ̿ѥȥ */
+GdkAtom atom_textmaid0;				/* ץ̿ѥȥ */
+GdkAtom atom_textmaid1;				/* ץ̿ѥȥ */
 GtkWidget *window;					/* ɥ */
 GtkWidget *notebook;				/* Ρȥ֥å */
 GtkWidget *status;					/* ơɥ */
@@ -94,13 +96,10 @@ static gchar *menu_translate(const gchar *path,gpointer func_data)
 int main(int argc,char *argv[])
 {
 	gboolean *arg_files;
-	gchar *arg,*endptr,*str,*section,*key;
-	gint i,j,k,l,m,opt,leng;
-	gint init_line=0;					/* ΥåȰ */
-	COMM *p;
+	gchar *arg,*section,*key;
+	gint i,count=0,leng,length=0;
 	PROFILE *profile;
 	TEXTWND *ptw;
-	GdkEventClient event;
 	GdkBitmap *mask;
 	GdkPixmap *pixmap;
 	GtkAccelGroup *accel_group;
@@ -160,23 +159,6 @@ int main(int argc,char *argv[])
 {N_("/_All"),                        "<control>A", command_all,     0,"<Item>"}};
 	/* Drag&Drop */
 	GtkTargetEntry drag_types[1]={{"text/uri-list",0,0}};
-	/* ޥɥ饤  */
-	struct arg_opt {
-		const char *name;
-		const int key;
-		const char *arg;
-		const char *doc;
-	};
-	const struct arg_opt arg_opts[]={
-	{"encoding",'c',"CHARSET",     N_("Character Encoding")},
-	{"history", 'h',"NUM",         N_("History")},
-	{"line",    'l',"NUM",         N_("Caret Position")},
-	{"new",     'n',"ON/OFF",      N_("New File")},
-	{"size",    's',"WIDTH,HEIGHT",N_("Window Size")},
-	{"second",  'x',"ON/OFF",      N_("Open Window")},
-	{"version", 'v',NULL,          N_("About")},
-	{"help",    '?',NULL,          N_("Help")},
-	{NULL,      0,  NULL,          NULL}};
 
 	/*  */
 	setlocale(LC_ALL,"");
@@ -398,108 +380,7 @@ int main(int argc,char *argv[])
 	}
 
 	/* ޥɥ饤β */
-	arg_files=g_malloc(argc*sizeof(gboolean));
-	memset(arg_files,0,argc*sizeof(gboolean));
-	i=1;/* i:Υץ,j:iʸ,k:iʹߤarg */
-	while (i<argc) {
-		if ((argv[i])[0]=='-') {/* ץ */
-			j=1;
-			k=i;
-			while ((argv[i])[j]!='\0' && (argv[i])[j]!='=') {
-				if ((argv[i])[1]=='-') {	/* Ĺץ */
-					opt=0;
-					for (l=0;arg_opts[l].name!=NULL;l++) {
-						leng=strlen(arg_opts[l].name);
-						if (g_strncasecmp(argv[i]+2,arg_opts[l].name,leng)==0
-											&& ((argv[i])[leng+2]=='\0'
-												|| (argv[i])[leng+2]=='=')) {
-							opt=arg_opts[l].key;
-							j=leng+2;
-							break;
-						}
-					}
-				} else {					/* ûץ */
-					opt=tolower((argv[i])[j++]);
-				}
-				arg=NULL;
-				for (l=0;arg_opts[l].name!=NULL;l++)
-					if (arg_opts[l].key==opt && arg_opts[l].arg!=NULL) {
-						if (i==k) {
-							for (m=2;(argv[i])[m]!='\0' && (argv[i])[m]!='=';
-																		m++);
-							arg=(argv[i])[m]=='\0'?argv[++k]:argv[i]+m+1;
-							k++;
-						} else {
-							arg=argv[k++];
-						}
-						if (arg==NULL || *arg=='\0')
-							opt=0;
-						break;
-					}
-				switch (opt) {
-					case 'c':
-						charset_set(arg);
-						break;
-					case 'h':
-						strval(&history,arg,10,TRUE);
-						if (history<0)
-							history=0;
-						else if (history>10)
-							history=10;
-						break;
-					case 'l':
-						strval(&init_line,arg,10,TRUE);
-						break;
-					case 'n':
-						newfile=g_strcasecmp(arg,"OK")==0
-												|| g_strcasecmp(arg,"ON")==0
-												|| g_strcasecmp(arg,"TRUE")==0
-												|| g_strcasecmp(arg,"YES")==0;
-						break;
-					case 's':
-						def_width=strtol(arg,&endptr,0);
-						def_height=strtol(++endptr,&endptr,0);
-						break;
-					case 'x':
-						second=g_strcasecmp(arg,"OK")==0
-												|| g_strcasecmp(arg,"ON")==0
-												|| g_strcasecmp(arg,"TRUE")==0
-												|| g_strcasecmp(arg,"YES")==0;
-						break;
-					case 'v':
-						g_print(
-"Text maid "VERSION"\n"
-"Copyright (C) 1998-2002 Iwamoto,Kazuki\n"
-"This is free software; see the source for copying conditions.  There is NO\n"
-"warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
-						);
-						g_free(arg_files);
-						return 0;
-					default:
-						g_print(
-"Copyright (c) 1998-2002 Iwamoto,Kazuki\n\n"
-"Usage: %s [OPTION...] [FILE...]\n\n",argv[0]);
-						for (i=0;arg_opts[i].name;i++) {
-							if (arg_opts[i].arg!=NULL)
-								str=g_strdup_printf("  -%c, --%s=%s",
-											arg_opts[i].key,arg_opts[i].name,
-															arg_opts[i].arg);
-							else
-								str=g_strdup_printf("  -%c, --%s",
-											arg_opts[i].key, arg_opts[i].name);
-							g_print("%-26s %s\n",str,gettext(arg_opts[i].doc));
-							g_free(str);
-						}
-						g_print("\n");
-						g_free(arg_files);
-						return 0;
-				}
-			}
-			i=i<k?k:i+1;
-		} else {/* ե */
-			arg_files[i++]=TRUE;
-		}
-	}
+	arg_files=arg_analyse(argv+1,TRUE);
 
 	/* ե륿 */
 	if (ftnum<=0) {
@@ -548,12 +429,16 @@ int main(int argc,char *argv[])
 	atom_targets=gdk_atom_intern("TARGETS",FALSE);
 	atom_compound=gdk_atom_intern("COMPOUND_TEXT",FALSE);
 	atom_text=gdk_atom_intern("TEXT",FALSE);
-	atom_textmaid=gdk_atom_intern("Text maid InterProcess communication",
+	atom_textmaid0=gdk_atom_intern("Text maid InterProcess communication 0",
+																		FALSE);
+	atom_textmaid1=gdk_atom_intern("Text maid InterProcess communication 1",
 																		FALSE);
 	gtk_selection_add_targets(window,atom_clipboard,
 							targets,sizeof(targets)/sizeof(GtkTargetEntry));
-	if (!second)
-		gtk_selection_add_targets(window,atom_textmaid,targets,1);
+	if (!second) {
+		gtk_selection_add_targets(window,atom_textmaid0,targets,1);
+		gtk_selection_add_targets(window,atom_textmaid1,targets,1);
+	}
 	gtk_signal_connect(GTK_OBJECT(window),"selection-clear-event",
 								GTK_SIGNAL_FUNC(signal_selection_clear),NULL);
 	gtk_signal_connect(GTK_OBJECT(window),"selection-get",
@@ -639,38 +524,40 @@ int main(int argc,char *argv[])
 
 	/* ˵ưƤ뤫å */
 	if (!second) {
-		gtk_selection_convert(window,atom_textmaid,
+		for (i=1;i<argc;i++) {
+			if (arg_files[i-1]) {
+				arg=get_full_path(argv[i]);
+				leng=strlen(arg)*sizeof(gchar);
+				arg_text=g_realloc(arg_text,length+leng+sizeof(gchar));
+				memcpy(arg_text+length,arg,leng);
+				g_free(arg);
+			} else {
+				leng=strlen(argv[i])*sizeof(gchar);
+				arg_text=g_realloc(arg_text,length+leng+sizeof(gchar));
+				memcpy(arg_text+length,argv[i],leng);
+			}
+			length+=leng;
+			arg_text[length++]='\n';
+		}
+		if (length>0) {
+			arg_text[length-1]='\0';
+			gtk_selection_owner_set(window,atom_textmaid1,GDK_CURRENT_TIME);
+		}
+		gtk_selection_convert(window,atom_textmaid0,
 								GDK_SELECTION_TYPE_STRING,GDK_CURRENT_TIME);
 		while (instance<0)
 			while (gtk_events_pending())
 				gtk_main_iteration();
 		if (instance>0) {
 			/* ˵ưƤȤ */
-			event.type=GDK_CLIENT_EVENT;
-			event.window=window->window;
-			event.send_event=TRUE;
-			event.message_type=atom_textmaid;
-			event.data_format=32;
-			event.data.l[0]=init_line;
-			event.data.l[4]=getpid();
-			gdk_event_send_clientmessage_toall((GdkEvent *)&event);
-			event.data_format=8;
-			for (i=1;i<argc;i++)
-				if (arg_files[i]) {
-					arg=get_full_path(argv[i]);
-					leng=strlen(arg)+1;
-					for (j=0;j<leng;j+=16) {
-						memcpy(event.data.b,arg+j,MIN(leng-j,16));
-						gdk_event_send_clientmessage_toall((GdkEvent *)&event);
-					}
-					g_free(arg);
-				}
+			while (arg_text!=NULL)
+				while (gtk_events_pending())
+					gtk_main_iteration();
 			g_free(arg_files);
 			gtk_exit(0);
 		}
-		gtk_signal_connect(GTK_OBJECT(window),"client-event",
-									GTK_SIGNAL_FUNC(signal_client_event),NULL);
-		gtk_selection_owner_set(window,atom_textmaid,GDK_CURRENT_TIME);
+		g_free(arg_text);
+		gtk_selection_owner_set(window,atom_textmaid0,GDK_CURRENT_TIME);
 	}
 
 	/* ɽ */
@@ -694,16 +581,15 @@ int main(int argc,char *argv[])
 	system_font=gdk_font_ref(style->font);
 
 	/* ɥ */
-	j=0;
 	for (i=1;i<argc;i++)
-		if (arg_files[i]) {
+		if (arg_files[i-1]) {
 			ptw=open_edit_file(argv[i]);
 			if (init_line!=0)	/* Ԥ˰ư */
 				jump_operation(ptw,init_line);
-			j++;
+			count++;
 		}
 	g_free(arg_files);
-	if (newfile && j<=0)
+	if (newfile && count<=0)
 		open_edit_file(NULL);
 
 	gtk_main();
@@ -914,11 +800,5 @@ int main(int argc,char *argv[])
 		g_free(ftype[i].fontname);
 	}
 	g_free(ftype);
-	while (comm!=NULL) {
-		g_free(comm->arg);
-		p=comm->next;
-		g_free(comm);
-		comm=p;
-	}
 	return 0;
 }
