@@ -112,12 +112,6 @@ typedef struct textwnd {
 	GtkWidget *label;			/* ֤Υ٥ */
 	GtkWidget *menu_item;		/* ˥塼Υɥι */
 } TEXTWND;
-typedef struct comm {
-	gchar *arg;
-	gint leng,init_line;
-	gint32 pid;
-	struct comm *prev,*next;
-} COMM;
 
 
 enum {
@@ -135,19 +129,21 @@ extern gchar *hisfile[10];				/* ե */
 extern gchar *openpath;					/* Υѥ */
 extern gchar *savepath;					/* ̾դ¸Υѥ */
 extern gchar *clipboard_text;			/* åץܡɤΥƥ */
+extern gchar *arg_text;					/* ץ̿ѿ */
 extern gint def_width,def_height;		/* ǥեȤΥɥΥ */
 extern gint ftnum;						/* ե륿פο */
 extern gint history;					/* ե */
+extern gint init_line;					/* ΥåȰ */
 extern gint instance;					/* ץ̿ѿ */
 extern gint tcount;						/* ե륿פΥ */
 extern guint timer_id;					/* ID */
-extern COMM *comm;						/* ץ̿ѹ¤ */
 extern FTYPE *ftype;					/* ե륿 */
 extern GdkAtom atom_clipboard;			/* åץܡ */
 extern GdkAtom atom_targets;			/* å */
 extern GdkAtom atom_compound;			/* ѥ */
 extern GdkAtom atom_text;				/* ƥ */
-extern GdkAtom atom_textmaid;			/* ץ̿ѥȥ */
+extern GdkAtom atom_textmaid0;			/* ץ̿ѥȥ */
+extern GdkAtom atom_textmaid1;			/* ץ̿ѥȥ */
 extern GtkWidget *window;				/* ɥ */
 extern GtkWidget *notebook;				/* Ρȥ֥å */
 extern GtkWidget *status;				/* ơɥ */
